@@ -286,14 +286,14 @@ class Console:
     Args:
         color_system (str, optional): The color system supported by your terminal,
             either ``"standard"``, ``"256"`` or ``"truecolor"``. Leave as ``"auto"`` to autodetect.
-        force_terminal (bool, optional): Force the Console to write control codes even when a terminal is not detected. Defaults to False.
-        force_jupyter (bool, optional): Force the Console to write to Jupyter even when Jupyter is not detected. Defaults to False
+        force_terminal (Optional[bool], optional): Enable/disable terminal control codes, or None to auto-detect terminal. Defaults to None.
+        force_jupyter (Optional[bool], optional): Enable/disable Jupyter rendering, or None to auto-detect Jupyter. Defaults to None.
         theme (Theme, optional): An optional style theme object, or ``None`` for default theme.
         file (IO, optional): A file object where the console should write to. Defaults to stdoutput.
         width (int, optional): The width of the terminal. Leave as default to auto-detect width.
         height (int, optional): The height of the terminal. Leave as default to auto-detect height.
         record (bool, optional): Boolean to enable recording of terminal output,
-            required to call :meth:`export_html` and :meth:`export_text`. Defaults to False.        
+            required to call :meth:`export_html` and :meth:`export_text`. Defaults to False.
         markup (bool, optional): Boolean to enable :ref:`console_markup`. Defaults to True.
         emoji (bool, optional): Enable emoji code. Defaults to True.
         highlight (bool, optional): Enable automatic highlighting. Defaults to True.
@@ -311,8 +311,8 @@ class Console:
         color_system: Optional[
             Literal["auto", "standard", "256", "truecolor", "windows"]
         ] = "auto",
-        force_terminal: bool = False,
-        force_jupyter: bool = False,
+        force_terminal: bool = None,
+        force_jupyter: bool = None,
         theme: Theme = None,
         file: IO[str] = None,
         width: int = None,
@@ -333,7 +333,7 @@ class Console:
         # Copy of os.environ allows us to replace it for testing
         self._environ = os.environ if _environ is None else _environ
 
-        self.is_jupyter = force_jupyter or _is_jupyter()
+        self.is_jupyter = _is_jupyter() if force_jupyter is None else force_jupyter
         if self.is_jupyter:
             width = width or 93
             height = height or 100
@@ -364,7 +364,9 @@ class Console:
 
         self._lock = threading.RLock()
         self._log_render = LogRender(
-            show_time=log_time, show_path=log_path, time_format=log_time_format,
+            show_time=log_time,
+            show_path=log_path,
+            time_format=log_time_format,
         )
         self.highlighter: HighlighterType = highlighter or _null_highlighter
         self.safe_box = safe_box
@@ -476,23 +478,21 @@ class Console:
             bool: True if the console writing to a device capable of
             understanding terminal codes, otherwise False.
         """
-        if self._force_terminal:
-            return True
+        if self._force_terminal is not None:
+            return self._force_terminal
         isatty = getattr(self.file, "isatty", None)
         return False if isatty is None else isatty()
 
     @property
     def is_dumb_terminal(self) -> bool:
         """Detect dumb terminal.
-        
+
         Returns:
             bool: True if writing to a dumb terminal, otherwise False.
-        
+
         """
-        is_dumb = "TERM" in self._environ and self._environ["TERM"].lower() in (
-            "dumb",
-            "unknown",
-        )
+        _term = self._environ.get("TERM", "")
+        is_dumb = _term.lower() in ("dumb", "unknown")
         return self.is_terminal and is_dumb
 
     @property
@@ -516,7 +516,7 @@ class Console:
         if self._width is not None and self._height is not None:
             return ConsoleDimensions(self._width, self._height)
 
-        if self.is_terminal and self.is_dumb_terminal:
+        if self.is_dumb_terminal:
             return ConsoleDimensions(80, 25)
 
         width, height = shutil.get_terminal_size()
@@ -560,7 +560,7 @@ class Console:
 
     def show_cursor(self, show: bool = True) -> None:
         """Show or hide the cursor.
-        
+
         Args:
             show (bool, optional): Set visibility of the cursor.
         """
@@ -585,6 +585,9 @@ class Console:
         """
 
         _options = options or self.options
+        if _options.max_width < 1:
+            # No space to render anything. This prevents potential recursion errors.
+            return
         render_iterable: RenderResult
         if isinstance(renderable, RichCast):
             renderable = renderable.__rich__()
@@ -735,7 +738,7 @@ class Console:
             renderables (Iterable[Union[str, ConsoleRenderable]]): Anyting that Rich can render.
             sep (str, optional): String to write between print data. Defaults to " ".
             end (str, optional): String to write at end of print data. Defaults to "\\n".
-            justify (str, optional): One of "left", "right", "center", or "full". Defaults to ``None``.       
+            justify (str, optional): One of "left", "right", "center", or "full". Defaults to ``None``.
             emoji (Optional[bool], optional): Enable emoji code, or ``None`` to use console default.
             markup (Optional[bool], optional): Enable markup, or ``None`` to use console default.
             highlight (Optional[bool], optional): Enable automatic highlighting, or ``None`` to use console default.
@@ -800,9 +803,9 @@ class Console:
         style: Union[str, Style] = "rule.line",
     ) -> None:
         """Draw a line with optional centered title.
-        
+
         Args:
-            title (str, optional): Text to render over the rule. Defaults to "".            
+            title (str, optional): Text to render over the rule. Defaults to "".
             characters (str, optional): Character(s) to form the line. Defaults to "─".
         """
         from .rule import Rule
@@ -910,7 +913,7 @@ class Console:
         word_wrap: bool = False,
     ) -> None:
         """Prints a rich render of the last exception and traceback.
-        
+
         Args:
             code_width (Optional[int], optional): Number of characters used to render code. Defaults to 88.
             extra_lines (int, optional): Additional lines of code to render. Defaults to 3.
@@ -983,7 +986,11 @@ class Console:
 
             renderables = [
                 self._log_render(
-                    self, renderables, path=path, line_no=line_no, link_path=link_path,
+                    self,
+                    renderables,
+                    path=path,
+                    line_no=line_no,
+                    link_path=link_path,
                 )
             ]
             for hook in self._render_hooks:
@@ -1041,12 +1048,13 @@ class Console:
             if style and not is_control:
                 append(
                     style.render(
-                        text, color_system=color_system, legacy_windows=legacy_windows,
+                        text,
+                        color_system=color_system,
+                        legacy_windows=legacy_windows,
                     )
                 )
-            else:
-                if not (not_terminal and is_control):
-                    append(text)
+            elif not (not_terminal and is_control):
+                append(text)
 
         rendered = "".join(output)
         return rendered
@@ -1060,7 +1068,7 @@ class Console:
         password: bool = False,
         stream: TextIO = None,
     ) -> str:
-        """Displays a prompt and waits for input from the user. The prompt may contain color / style. 
+        """Displays a prompt and waits for input from the user. The prompt may contain color / style.
 
         Args:
             prompt (Union[str, Text]): Text to render in the prompt.
@@ -1068,7 +1076,7 @@ class Console:
             emoji (bool, optional): Enable emoji (requires a str prompt). Defaults to True.
             password: (bool, optional): Hide typed text. Defaults to False.
             stream: (TextIO, optional): Optional file to read input from (rather than stdin). Defaults to None.
-        
+
         Returns:
             str: Text read from stdin.
         """
